@@ -92,15 +92,16 @@ no warnings 'uninitialized';
 
 use Data::Dumper;
 
+use Socket;
 use IO::Socket::INET;
 use POSIX ":sys_wait_h";
 
 use vars qw($VERSION);
 
-$VERSION = '1.71';
+$VERSION = '1.72';
 
 
-$Lock::Server::DEBUG = 0;
+$Lock::Server::DEBUG = 1;
 
 =head2 Lock::Server::new( $args )
 
@@ -233,6 +234,7 @@ sub _create_listener_socket {
     until( $listener_socket || $count++ > $self->{attempts} ) {
         $listener_socket = new IO::Socket::INET(
             Listen    => 10,
+            Type      => SOCK_STREAM,
             LocalAddr => "$self->{host}:$self->{port}",
             );
         last if $listener_socket;
@@ -260,57 +262,48 @@ sub _create_listener_socket {
         _log( "lock server  : got INT signal. EXITING." );
         exit;
     };
+    setsockopt( $listener_socket, SOL_SOCKET, SO_KEEPALIVE, 1 );
     return $listener_socket;
 } #_create_listener_socket
 
 sub _run_loop {
     my( $self, $listener_socket ) = @_;
-
     while( my $connection = $listener_socket->accept ) {
-        local $SIG{ALRM} = sub {
-            die "ALARM\n";
-        };
-        alarm( $self->{lock_attempt_timeout} + 1 );
-        eval {
-            my $req = <$connection>; 
-            $req =~ s/\s+$//s;
-            _log( "lock server : incoming request : '$req'" );
-            # could have headers, but ignore those. Find \n\n
-            while( my $data = <$connection> ) {
-                chomp $data;
-                last unless $data =~ /\S/;
-            }
+        my $req = <$connection>; 
+        $req =~ s/\s+$//s;
+        _log( "lock server : incoming request : '$req'" );
+        # could have headers, but ignore those. Find \n\n
+        while( my $data = <$connection> ) {
+            chomp $data;
+            last unless $data =~ /\S/;
+        }
 
-            my( $cmd, $key, $locker_id ) = split( '/', substr( $req, 5 ) );
-            if( $cmd eq 'CHECK' ) {
-                $self->_check( $connection, $key );
-            } elsif( $cmd eq 'LOCK' ) {
-                $self->_lock( $connection, $key, $locker_id );
-            } elsif( $cmd eq 'UNLOCK' ) {
-                $self->_unlock( $connection, $key, $locker_id );
-            } elsif( $cmd eq 'VERIFY' ) {
-                $self->_verify( $connection, $key, $locker_id );
-            } elsif( $cmd eq 'PING' ) {
+        my( $cmd, $key, $locker_id ) = split( '/', substr( $req, 5 ) );
+        if( $cmd eq 'CHECK' ) {
+            $self->_check( $connection, $key );
+        } elsif( $cmd eq 'LOCK' ) {
+            $self->_lock( $connection, $key, $locker_id );
+        } elsif( $cmd eq 'UNLOCK' ) {
+            $self->_unlock( $connection, $key, $locker_id );
+        } elsif( $cmd eq 'VERIFY' ) {
+            $self->_verify( $connection, $key, $locker_id );
+        } elsif( $cmd eq 'PING' ) {
+            print $connection "1\n";
+            $connection->close;
+        } elsif( $cmd eq 'SHUTDOWN') {
+            if( $self->{allow_shutdown}) {
                 print $connection "1\n";
                 $connection->close;
-            } elsif( $cmd eq 'SHUTDOWN') {
-                if( $self->{allow_shutdown}) {
-                    print $connection "1\n";
-                    $connection->close;
-                    $self->stop;
-                } else {
-                    _log( "lock server : got shutdown request but not configured to allow it" );
-                    $connection->close;
-                }
+                $self->stop;
             } else {
-                _log( "lock server : did not understand command '$cmd'" );
+                _log( "lock server : got shutdown request but not configured to allow it" );
                 $connection->close;
             }
-        };
-        if( $@ ) {
+        } else {
+            _log( "lock server : did not understand command '$cmd'" );
             $connection->close;
         }
-    }
+    } #while still getting connections
 } #_run_loop
 
 sub _check {
@@ -371,6 +364,7 @@ sub _lock {
     if( 0 < (grep { $_ eq $locker_id } @$lockers) ) {
         _log( "lock request error. '$locker_id' already in the lock queue" );
         print $connection "0\n";
+        $connection->close;
         return;
     }
 
@@ -395,7 +389,7 @@ sub _lock {
                 exit;
             };
             $SIG{HUP} = sub {
-                _log( "lock request : child got HUP, so is now locked." );
+                _log( "lock request : child got HUP, so is now locked. exiting" );
                 $connection->print( "$timeout_time\n" );
                 $connection->close;
                 exit;
@@ -656,6 +650,6 @@ __END__
 
 =head1 VERSION
 
-       Version 1.71  (June 1, 2016))
+       Version 1.72  (June 1, 2016))
 
 =cut
